WallpaperPlugin class

Constructors

WallpaperPlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

setWallpaperFromRepaintBoundary(GlobalKey<State<StatefulWidget>> boundaryKey, String target, {double pixelRatio = 2.5}) Future<bool>
useAsImageFromRepaintBoundary(GlobalKey<State<StatefulWidget>> boundaryKey, {double pixelRatio = 2.5}) Future<bool>